package de.hdm_stuttgart.battlearena.Model.DataStorage.Classes.Utilities;

//import de.hdm_stuttgart.battlearena.Model.DataStorage.Classes.Exceptions.CryptoException;

import de.hdm_stuttgart.battlearena.Model.DataStorage.Classes.Exceptions.CryptoException;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.junit.jupiter.api.*;

import java.io.*;

import static org.junit.jupiter.api.Assertions.*;

public class CryptoUtilsTest {
    private static File encryptiondecryptiontestFile = new File("src\\main\\resources\\database\\encryptiondecryptiontestFile.txt");
    private static File encryptedtestFile = new File("src\\main\\resources\\database\\encrypted;encryptedtestFile.txt");
    private static boolean alreadyencrypted;
    private static int encryptionreturn;
    private static String text="";
    private static String[] parts;
    private static String testtext = "Hier steht ein Testtext.";
    private static boolean multipleencryptions = false;
    private static final Logger log = LogManager.getLogger(CryptoUtilsTest.class);

    @BeforeEach
    void beforeEachTest(TestInfo testInfo) {
        log.info(() -> String.format("About to execute [%s]",
                testInfo.getDisplayName()));
    }
    @AfterEach
    void afterEachTest(TestInfo testInfo) {
        log.info(() -> String.format("Finished executing [%s]",
                testInfo.getDisplayName()));
    }
    @Test
    void encryptDecryptiontest() throws IOException {
        BufferedWriter writer = new BufferedWriter(new FileWriter(encryptiondecryptiontestFile));
        writer.write(testtext);
        writer.close();
        try {
            CryptoUtils.encrypt(encryptiondecryptiontestFile, true);
            parts = CryptoUtils.decrypt(encryptiondecryptiontestFile);
            text = parts[0];
            System.out.println(text);
        } catch (CryptoException ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        assertEquals(testtext,text);
    }
    @RepeatedTest(3)
    void repeatedCheckFileEncryptingMultipleTimes() throws IOException {
        BufferedWriter writer = new BufferedWriter(new FileWriter(encryptiondecryptiontestFile));
        writer.write(testtext);
        writer.close();
        try {
            encryptionreturn = CryptoUtils.encrypt(encryptiondecryptiontestFile, true);
            parts = CryptoUtils.decrypt(encryptiondecryptiontestFile);
            text = parts[0];
            System.out.println(text);
        } catch (CryptoException ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        assertEquals(encryptionreturn, 0);
        assertEquals(testtext,text);            //Change
    }
    @Test
    void checkFileEncryptingOnce() throws IOException {
        BufferedWriter writer = new BufferedWriter(new FileWriter(encryptiondecryptiontestFile));
        writer.write(testtext);
        writer.close();
        try {
            encryptionreturn = CryptoUtils.encrypt(encryptiondecryptiontestFile, false);
            parts = CryptoUtils.decrypt(encryptiondecryptiontestFile);
            text = parts[0];
            System.out.println(text);
        } catch (CryptoException ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        assertEquals(encryptionreturn, 1);
        assertEquals(testtext,text);        //Change
    }
    @Test
    void checkIfFileAlreadyEncrypted(){
        alreadyencrypted = CryptoUtils.check_if_file_already_encrypted(encryptedtestFile);
        assertTrue(alreadyencrypted);
    }
    @Test
    void checkIfFileNotYetEncrypted(){
        alreadyencrypted = CryptoUtils.check_if_file_already_encrypted(encryptiondecryptiontestFile);
        assertFalse(alreadyencrypted);
    }
    @Test
    void exceptionTestingFileNotFound() {
        CryptoException exception = assertThrows(CryptoException.class, () ->
                CryptoUtils.decrypt(new File("src/main/resources/database/thisFileShouldn'tExist")));
        assertEquals("Error encrypting/decrypting file", exception.getMessage());
    }
}
